<?php

namespace Drupal\thesimpsons\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Component\Serialization\Json;

/**
 * Provides a 'The Simpsons' block.
 *
 * @Block (
 *  id = "thesimpsons_block",
 *  category = @Translation("The Simpsons"),
 *  admin_label = @Translation("The Simpsons quote of the day"),
 *  module = "simpsons"
 *  )
 */
class TheSimpsonsBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('thesimpsons.settings');
    $language = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $connection = \Drupal::database();
    $quote = $connection->select('thesimpsons', 't')
      ->fields('t', [
        'quote'
      ])
      ->orderRandom()
      ->range(0, 1)
      ->execute()
      ->fetchField();
    $url = 'https://api.mymemory.translated.net/get?q='.$quote.'&langpair=en|'.$language;
    $response = \Drupal::httpClient()->get($url);
    $data = Json::decode($response->getBody());
    return [
      '#type' => 'markup',
      '#markup' => $config->get('translate') && $language !== 'en'
        ? nl2br(htmlspecialchars($data['responseData']['translatedText']))
        : nl2br(htmlspecialchars($quote))
    ];
  }

  /*
   * {inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
